@@ -47,7 +47,6 @@ extern "C" {
 
 typedef struct _AviEdit AviEdit;
 typedef struct _AviFrame AviFrame;
-typedef struct _AviOptions AviOptions;
 typedef struct _AviPcm AviPcm;
 typedef struct _AviSave AviSave;
 
@@ -357,48 +356,6 @@ gboolean
 avi_release (AviEdit *avi_edit);
 
 
-#ifdef DEPRECATED
-/*  ja:AVIのデータのバイト数を取得する
-    avi_edit,AVI編集ハンドル
-       start,読み込みをはじめるサンプル番号
-     samples,サンプル数
-         RET,バイト数                                                       */
-gint
-avi_sample_size (AviEdit    *avi_edit,
-                 const gint  start,
-                 const gint  samples);
-
-
-/*  ja:AVIのデータを読み込む
-    avi_edit,AVI編集ハンドル
-       start,読み込みをはじめるサンプル番号
-     samples,サンプル数
-      buffer,データを格納するバッファ
-         RET,TRUE:正常終了,FALSE:エラー                                     */
-gboolean
-avi_read (AviEdit    *avi_edit,
-          const gint  start,
-          const gint  samples,
-          gpointer    buffer);
-
-
-/*  ja:AVIのフォーマットのサイズを取得する
-    avi_edit,AVI編集ハンドル
-         RET,フォーマットのバイト数,0:エラー                                */
-gint
-avi_format_size (AviEdit *avi_edit);
-
-
-/*  ja:AVIのフォーマットを読み込む
-    avi_edit,AVI編集ハンドル
-      format,バッファへのポインタ
-         RET,TRUE:正常終了,FALSE:エラー                                     */
-gboolean
-avi_read_format (AviEdit  *avi_edit,
-                 gpointer  format);
-#endif /* DEPRECATED */
-
-
 /******************************************************************************
 *                                                                             *
 * ja:フレーム関数                                                             *
@@ -476,8 +433,8 @@ avi_get_pcm_close (AviPcm *avi_pcm);
 
 /*  ja:PCMに展開されたオーディオを取得する
         avi_pcm,AVIPCM構造体
-          start,取得するサンプル番号
-        samples,サンプル数
+          start,取得する仮想サンプル番号
+        samples,仮想サンプル数
         out_buf,PCMデータ
     out_samples,PCMデータの実サンプル数
             RET,TRUE:正常終了,FALSE:エラー                                  */
@@ -575,21 +532,6 @@ avi_save_is_all (AviEdit **avi_edit,
                  AviSave  *avi_save);
 
 
-/*  ja:ファイルに保存する
-     avi_edit,AVI編集ハンドルへのポインタ
-         file,ファイル名
-      avi_opt,オプション
-         func,コールバック関数
-    user_data,データ
-          RET,TRUE:正常終了,FALSE:エラー                                    */
-gboolean
-avi_save_avi (AviEdit     *avi_edit[],
-              const gchar *file,
-              AviOptions  *avi_opt,
-              gboolean   (*func)(gint, gpointer),
-              gpointer     user_data);
-
-
 /*  ja:ビットマップファイルに保存する
      avi_edit,AVI編集ハンドル
          file,ファイル名
@@ -608,16 +550,20 @@ avi_save_bitmap (AviEdit      *avi_edit,
 
 
 /*  ja:WAVEファイルに保存する
-     avi_edit,AVI編集ハンドル
-         file,ファイル名
-         func,コールバック関数
-    user_data,データ
-          RET,TRUE:正常終了,FALSE:エラー                                    */
+      avi_edit,AVI編集ハンドル
+          file,ファイル名
+           wfx,WaveFormatEx構造体へのポインタ(NULL:PCM)
+    recompress,TRUE:再圧縮,FALSE:差分圧縮(wfxがNULLならば無視)
+          func,コールバック関数
+     user_data,データ
+           RET,TRUE:正常終了,FALSE:エラー                                   */
 gboolean
-avi_save_wave (AviEdit   *avi_edit,
-               const      gchar *file,
-               gboolean (*func)(gint, gpointer),
-               gpointer   user_data);
+avi_save_wave (AviEdit             *avi_edit,
+               const gchar         *file,
+               const WaveFormatEx  *wfx,
+               const gboolean       recompress,
+               gboolean           (*func)(gint, gpointer),
+               gpointer             user_data);
 
 
 /*  ja:ファイルに保存する
