@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -71,6 +71,465 @@ avi_save_is_all (AviEdit **avi_edit,
 }
 
 
+/*  ja:ビットマップファイルに保存する
+     avi_edit,AVI編集ハンドル
+         file,ファイル名
+        start,最初のフレーム
+          end,最後のフレーム
+         func,コールバック関数
+    user_data,データ
+          RET,TRUE:正常終了,FALSE:エラー                                    */
+gboolean
+avi_save_bitmap (AviEdit      *avi_edit,
+                 const gchar  *file,
+                 const gint    start,
+                 const gint    end,
+                 gboolean    (*func)(gint, gpointer),
+                 gpointer      user_data)
+{
+  gboolean result = TRUE;
+  gchar *format, *dir, *name, *ext;
+  gint i, s;
+  AviFrame *avi_frame;
+  BitmapFileHeader bmfh;
+
+  if (!avi_edit || !file)
+    return FALSE;
+  dir = g_dirname (file);
+  name = g_strdup (g_basename (file));
+  for (i = g_strlen (name) - 1; i >= 0; i--)
+    if (name[i] == '.')
+      break;
+  if (i >= 0)
+    {
+      ext = g_strdup (name + i);
+      name[i] = '\0';
+    }
+  else
+    {
+      ext = g_strdup ("");
+    }
+  for (i = 0, s = end; s != 0; s /= 10)
+    i++;
+  format = g_strdup_printf ("%s/%s%%0%dd%s", dir, name, i, ext);
+  g_free (dir);
+  g_free (name);
+  g_free (ext);
+
+  g_memset (&bmfh, 0, BMFH_SIZE);
+  bmfh_set_type (&bmfh ,0x4d42);
+  bmfh_set_size (&bmfh, bm_all_bytes (avi_edit->bmih) + BMFH_SIZE);
+  bmfh_set_off_bits (&bmfh, bm_header_bytes (avi_edit->bmih) + BMFH_SIZE);
+
+  avi_frame = avi_get_frame_open (avi_edit);
+  if (!avi_frame)
+    {
+      g_free (format);
+      return FALSE;
+    }
+  for (i = start; i <= end; i++)
+    {
+      FileIO *fio;
+      gint length;
+      BitmapInfoHeader *bmih;
+
+      /* ja:中断チェック */
+      if (func && !func ((i - start) * 100/(end - start + 1), user_data))
+        break;
+
+      bmih = avi_get_frame (avi_frame, i, bmih_get_width (avi_edit->bmih),
+                                          bmih_get_height (avi_edit->bmih),
+                                          bmih_get_bit_count (avi_edit->bmih));
+      if (!bmih)
+        {
+          result = FALSE;
+          break;
+        }
+      bmih_set_x_pixels_per_meter (bmih,
+                                bmih_get_x_pixels_per_meter (avi_edit->bmih));
+      bmih_set_y_pixels_per_meter (bmih,
+                                bmih_get_y_pixels_per_meter (avi_edit->bmih));
+      length = bm_all_bytes (bmih);
+
+      name = start == end ? g_strdup (file) : g_strdup_printf (format, i);
+      /* bmihファイルを開く */
+      fio = fileio_open (name, FILEIO_ACCESS_ALL,
+                                    FILEIO_SHARE_READ, FILEIO_MODE_CREATE_NEW);
+      g_free (name);
+      if (!fio)
+        {
+          result = FALSE;
+          break;
+        }
+      if (fileio_write (fio, &bmfh, BMFH_SIZE) != BMFH_SIZE
+                                || fileio_write (fio, bmih, length) != length)
+        {
+          fileio_close (fio);
+          result = FALSE;
+          break;
+        }
+      if (!fileio_close (fio))
+        {
+          result = FALSE;
+          break;
+        }
+    }
+  g_free (format);
+  return avi_get_frame_close (avi_frame) && result;
+}
+
+
+/*  ja:WAVEファイルに保存する
+      avi_edit,AVI編集ハンドル
+          file,ファイル名
+           wfx,WaveFormatEx構造体へのポインタ(NULL:PCM)
+    recompress,TRUE:再圧縮,FALSE:差分圧縮(wfxがNULLならば無視)
+          func,コールバック関数
+     user_data,データ
+           RET,TRUE:正常終了,FALSE:エラー                                   */
+gboolean
+avi_save_wave (AviEdit             *avi_edit,
+               const gchar         *file,
+               const WaveFormatEx  *wfx,
+               const gboolean       recompress,
+               gboolean           (*func)(gint, gpointer),
+               gpointer             user_data)
+{
+  FileIO *fio;
+  gpointer head;
+  gsize header_bytes;
+  guint8 *p;
+  gint written = 0, header;
+  AviPcm *avi_pcm;
+  AcmObject *acm_object = NULL;
+
+  if (!avi_edit || !file || (wfx && wfx_get_format_tag (wfx) == WAVE_FMT_PCM))
+    return FALSE;
+  header_bytes = wfx ? wf_header_bytes (wfx) : WFX_SIZE - sizeof (guint16);
+  /* ja:ヘッタサイズを計算する */
+  header = sizeof (guint32)                                     /* en:'RIFF' */
+            + sizeof (guint32)                                  /* ja:サイズ */
+            + sizeof (guint32)                                  /* en:'WAVE' */
+            + sizeof (guint32)                                  /* en:'fmt ' */
+            + sizeof (guint32)                                  /* ja:サイズ */
+            + ((header_bytes + 1) & ~1)                         /* ja:構造体 */
+            + sizeof (guint32)                                  /* en:'data' */
+            + sizeof (guint32);                                 /* ja:サイズ */
+  /* ja:ファイルを開く */
+  fio = fileio_open (file, FILEIO_ACCESS_ALL,
+                                    FILEIO_SHARE_READ, FILEIO_MODE_CREATE_NEW);
+  if (!fio)
+    return FALSE;
+  if (fileio_seek (fio, header, FILEIO_SEEK_SET) == -1)
+    {
+      fileio_close (fio);
+      return FALSE;
+    }
+  /* ja:データ */
+  avi_pcm = avi_get_pcm_open (avi_edit);
+  if (!avi_pcm)
+    {
+      fileio_close (fio);
+      return FALSE;
+    }
+  if (wfx && !(acm_object = acm_open (wfx_get_format_tag (wfx))))
+    {
+      avi_get_pcm_close (avi_pcm);
+      fileio_close (fio);
+      return FALSE;
+    }
+  if (wfx && !recompress)
+    { /* ja:差分圧縮 */
+      gboolean flag = TRUE, acm = FALSE;
+      gint offset = 0;
+      AviFile *avi_file;
+
+      for (avi_file = avi_edit->file; avi_file->prev;
+                                                    avi_file = avi_file->prev);
+      while (avi_file && flag)
+        {
+          if (wf_header_bytes (avi_file->wfx) == wf_header_bytes (wfx)
+                && g_memcmp (avi_file->wfx, wfx, wf_header_bytes (wfx)) == 0)
+            { /* ja:再利用 */
+              gint pos = 0, samples, leng;
+
+              leng = avi_audio_virtual_to_real (avi_file->length, wfx);
+              samples = MAX (wfx_get_average_bytes_per_sec (wfx)
+                                            / wfx_get_block_align (wfx), 1);
+              while (pos < leng)
+                {
+                  gpointer buffer;
+                  gint length;
+
+                  /* ja:中断チェック */
+                  if (func
+                    && !(flag = func ((offset + avi_file->length * pos / leng)
+                                    * 100 / avi_length (avi_edit), user_data)))
+                    break;
+                  if (leng < pos + samples)
+                    samples = leng - pos;
+                  buffer = g_malloc (avi_read_audio_size (avi_file,
+                                                                pos, samples));
+                  if (!avi_read_audio (avi_file, pos, samples, buffer))
+                    {
+                      acm_close (acm_object);
+                      avi_get_pcm_close (avi_pcm);
+                      fileio_close (fio);
+                      return FALSE;
+                    }
+                  pos += samples;
+                  length = samples * wfx_get_block_align (wfx);
+                  if (fileio_write (fio, buffer, length) != length)
+                    {
+                      g_free (buffer);
+                      acm_close (acm_object);
+                      avi_get_pcm_close (avi_pcm);
+                      fileio_close (fio);
+                      return FALSE;
+                    }
+                  g_free (buffer);
+                  written += length;
+                }
+            }
+          else
+            { /* ja:圧縮 */
+              gint pos = 0, samples = AVI_PCM_SAMPLES_PER_SEC;
+
+              if (!acm)
+                {
+                  if (!acm_compress_begin (acm_object, avi_edit->wfx, wfx))
+                    {
+                      acm_close (acm_object);
+                      avi_get_pcm_close (avi_pcm);
+                      fileio_close (fio);
+                      return FALSE;
+                    }
+                  acm = TRUE;
+                }
+              while (pos < avi_file->length)
+                {
+                  gpointer out_buf, acm_buf;
+                  gint out_samples, acm_samples, length;
+
+                  /* ja:中断チェック */
+                  if (func && !(flag = func ((pos + offset) * 100
+                                        / avi_length (avi_edit), user_data)))
+                    break;
+                  if (avi_edit->length < pos + samples)
+                    samples = avi_edit->length - pos;
+                  if (!avi_get_pcm (avi_pcm, pos + offset, samples,
+                                                    &out_buf, &out_samples))
+                    {
+                      acm_compress_end (acm_object, NULL, NULL);
+                      acm_close (acm_object);
+                      avi_get_pcm_close (avi_pcm);
+                      fileio_close (fio);
+                      return FALSE;
+                    }
+                  pos += samples;
+                  if (!acm_compress (acm_object,
+                                out_buf, out_samples, &acm_buf, &acm_samples))
+                    {
+                      g_free (out_buf);
+                      acm_compress_end (acm_object, NULL, NULL);
+                      acm_close (acm_object);
+                      avi_get_pcm_close (avi_pcm);
+                      fileio_close (fio);
+                      return FALSE;
+                    }
+                  g_free (out_buf);
+                  length = acm_samples * wfx_get_block_align (wfx);
+                  if (length > 0
+                            && fileio_write (fio, acm_buf, length) != length)
+                    {
+                      g_free (acm_buf);
+                      acm_compress_end (acm_object, NULL, NULL);
+                      acm_close (acm_object);
+                      avi_get_pcm_close (avi_pcm);
+                      fileio_close (fio);
+                      return FALSE;
+                    }
+                  g_free (acm_buf);
+                  written += length;
+                }
+              if (!avi_file->next || (wf_header_bytes (avi_file->next->wfx)
+                                                    == wf_header_bytes (wfx)
+                                        && g_memcmp (avi_file->next->wfx, wfx,
+                                                wf_header_bytes (wfx)) == 0))
+                {
+                  gpointer acm_buf;
+                  gint acm_samples, length;
+
+                  if (!acm_compress_end (acm_object, &acm_buf, &acm_samples))
+                    {
+                      acm_close (acm_object);
+                      avi_get_pcm_close (avi_pcm);
+                      g_free (acm_buf);
+                      fileio_close (fio);
+                      return FALSE;
+                    }
+                  length = acm_samples * wfx_get_block_align (wfx);
+                  if (length > 0
+                            && fileio_write (fio, acm_buf, length) != length)
+                    {
+                      g_free (acm_buf);
+                      avi_get_pcm_close (avi_pcm);
+                      fileio_close (fio);
+                      return FALSE;
+                    }
+                  g_free (acm_buf);
+                  written += length;
+                  acm = FALSE;
+                }
+            }
+          offset = avi_file->length;
+          avi_file = avi_file->next;
+        }
+    }
+  else
+    { /* ja:PCMまたは再圧縮 */
+      gint pos = 0, samples = AVI_PCM_SAMPLES_PER_SEC;
+
+      if (acm_object && !acm_compress_begin (acm_object, avi_edit->wfx, wfx))
+        {
+          acm_close (acm_object);
+          avi_get_pcm_close (avi_pcm);
+          fileio_close (fio);
+          return FALSE;
+        }
+      while (pos < avi_length (avi_edit))
+        {
+          gpointer out_buf;
+          gint out_samples, length;
+
+          /* ja:中断チェック */
+          if (func && !func (pos * 100 / avi_length (avi_edit), user_data))
+            break;
+          if (avi_length (avi_edit) < pos + samples)
+            samples = avi_length (avi_edit) - pos;
+          if (!avi_get_pcm (avi_pcm, pos, samples, &out_buf, &out_samples))
+            {
+              if (acm_object)
+                {
+                  acm_compress_end (acm_object, NULL, NULL);
+                  acm_close (acm_object);
+                }
+              avi_get_pcm_close (avi_pcm);
+              fileio_close (fio);
+              return FALSE;
+            }
+          pos += samples;
+          if (acm_object)
+            {
+              gpointer acm_buf;
+              gint acm_samples;
+
+              if (!acm_compress (acm_object,
+                                out_buf, out_samples, &acm_buf, &acm_samples))
+                {
+                  g_free (out_buf);
+                  acm_compress_end (acm_object, NULL, NULL);
+                  acm_close (acm_object);
+                  avi_get_pcm_close (avi_pcm);
+                  fileio_close (fio);
+                  return FALSE;
+                }
+              g_free (out_buf);
+              out_buf = acm_buf;
+              length = acm_samples * wfx_get_block_align (wfx);
+            }
+          else
+            {
+              length = out_samples * wfx_get_block_align (avi_edit->wfx);
+            }
+          if (length > 0 && fileio_write (fio, out_buf, length) != length)
+            {
+              g_free (out_buf);
+              if (acm_object)
+                {
+                  acm_compress_end (acm_object, NULL, NULL);
+                  acm_close (acm_object);
+                }
+              avi_get_pcm_close (avi_pcm);
+              fileio_close (fio);
+              return FALSE;
+            }
+          g_free (out_buf);
+          written += length;
+        }
+      if (acm_object)
+        {
+          gpointer acm_buf;
+          gint acm_samples, length;
+
+          if (!acm_compress_end (acm_object, &acm_buf, &acm_samples))
+            {
+              acm_close (acm_object);
+              avi_get_pcm_close (avi_pcm);
+              g_free (acm_buf);
+              fileio_close (fio);
+              return FALSE;
+            }
+          length = acm_samples * wfx_get_block_align (wfx);
+          if (length > 0 && fileio_write (fio, acm_buf, length) != length)
+            {
+              g_free (acm_buf);
+              acm_close (acm_object);
+              avi_get_pcm_close (avi_pcm);
+              fileio_close (fio);
+              return FALSE;
+            }
+          g_free (acm_buf);
+          written += length;
+        }
+    }
+  if ((acm_object && !acm_close (acm_object)) | !avi_get_pcm_close (avi_pcm))
+    {
+      fileio_close (fio);
+      return FALSE;
+    }
+  if (written & 1)
+    {
+      const static guint8 dmy = 0;
+
+      if (fileio_write (fio, &dmy, 1) != 1)
+        {
+          fileio_close (fio);
+          return FALSE;
+        }
+    }
+  /* ja:ヘッタを設定する */
+  p = head = g_malloc (header);
+  *(guint32 *)p = GUINT32_TO_LE (CK_DEF_RIFF);
+  ((guint32 *)p)++;                                             /* en:'RIFF' */
+  *(guint32 *)p = GUINT32_TO_LE (header - sizeof (guint32) * 2
+                                                    + ((written + 1) & ~1));
+  ((guint32 *)p)++;                                             /* ja:サイズ */
+  *(guint32 *)p = GUINT32_TO_LE (CK_FORM_WAVE);
+  ((guint32 *)p)++;                                             /* en:'WAVE' */
+  *(guint32 *)p = GUINT32_TO_LE (CK_ID_WAVEFORMAT);
+  ((guint32 *)p)++;                                             /* en:'fmt ' */
+  *(guint32 *)p = GUINT32_TO_LE (header_bytes);
+  ((guint32 *)p)++;                                             /* ja:サイズ */
+  g_memmove (p, wfx ? wfx : avi_edit->wfx, header_bytes);
+  if (header_bytes & 1)
+    p[header_bytes] = 0;
+  p += (header_bytes + 1) & ~1;
+  *(guint32 *)p = GUINT32_TO_LE (CK_ID_WAVEDATA);
+  ((guint32 *)p)++;                                             /* en:'data' */
+  *(guint32 *)p = GUINT32_TO_LE (written);                      /* ja:サイズ */
+  if (fileio_seek (fio, 0 , FILEIO_SEEK_SET) == -1
+                                || fileio_write (fio, head, header) != header)
+    {
+      fileio_close (fio);
+      g_free (head);
+      return FALSE;
+    }
+  g_free (head);
+  return fileio_close (fio);
+}
+
+
 typedef struct _AviSaveAviStream
 {
   gboolean active;          /* ja:TRUE:圧縮on,FALSE:圧縮off */
@@ -346,7 +805,7 @@ avi_save_avi_write (FileIO            *fio,
          func,コールバック関数
     user_data,データ
           RET,TRUE:正常終了,FALSE:エラー                                    */
-gboolean
+static gboolean
 avi_save_avi (AviEdit      *avi_edit[],
               const gchar  *file,
               AviOptions   *avi_opt,
@@ -380,7 +839,8 @@ avi_save_avi (AviEdit      *avi_edit[],
   if (streams <= 0)
     return FALSE;
   if (streams == 1 && avi_type (avi_edit[0]) == AVI_TYPE_AUDIO)
-    return avi_save_wave (avi_edit[0], file, func, user_data);
+    return avi_save_wave (avi_edit[0], file,
+                    avi_opt[0].wfx, avi_opt[0].recompress, func, user_data);
   stream = g_malloc0 (streams * sizeof (AviSaveAviStream));
 
   /* ja:ヘッタサイズを計算する */
@@ -1068,236 +1528,6 @@ avi_save_avi (AviEdit      *avi_edit[],
 }
 
 
-/*  ja:ビットマップファイルに保存する
-     avi_edit,AVI編集ハンドル
-         file,ファイル名
-        start,最初のフレーム
-          end,最後のフレーム
-         func,コールバック関数
-    user_data,データ
-          RET,TRUE:正常終了,FALSE:エラー                                    */
-gboolean
-avi_save_bitmap (AviEdit      *avi_edit,
-                 const gchar  *file,
-                 const gint    start,
-                 const gint    end,
-                 gboolean    (*func)(gint, gpointer),
-                 gpointer      user_data)
-{
-  gboolean result = TRUE;
-  gchar *format, *dir, *name, *ext;
-  gint i, s;
-  AviFrame *avi_frame;
-  BitmapFileHeader bmfh;
-
-  if (!avi_edit || !file)
-    return FALSE;
-  dir = g_dirname (file);
-  name = g_strdup (g_basename (file));
-  for (i = g_strlen (name) - 1; i >= 0; i--)
-    if (name[i] == '.')
-      break;
-  if (i >= 0)
-    {
-      ext = g_strdup (name + i);
-      name[i] = '\0';
-    }
-  else
-    {
-      ext = g_strdup ("");
-    }
-  for (i = 0, s = end; s != 0; s /= 10)
-    i++;
-  format = g_strdup_printf ("%s/%s%%0%dd%s", dir, name, i, ext);
-  g_free (dir);
-  g_free (name);
-  g_free (ext);
-
-  g_memset (&bmfh, 0, BMFH_SIZE);
-  bmfh_set_type (&bmfh ,0x4d42);
-  bmfh_set_size (&bmfh, bm_all_bytes (avi_edit->bmih) + BMFH_SIZE);
-  bmfh_set_off_bits (&bmfh, bm_header_bytes (avi_edit->bmih) + BMFH_SIZE);
-
-  avi_frame = avi_get_frame_open (avi_edit);
-  if (!avi_frame)
-    {
-      g_free (format);
-      return FALSE;
-    }
-  for (i = start; i <= end; i++)
-    {
-      FileIO *fio;
-      gint length;
-      BitmapInfoHeader *bmih;
-
-      /* ja:中断チェック */
-      if (func && !func ((i - start) * 100/(end - start + 1), user_data))
-        break;
-
-      bmih = avi_get_frame (avi_frame, i, bmih_get_width (avi_edit->bmih),
-                                          bmih_get_height (avi_edit->bmih),
-                                          bmih_get_bit_count (avi_edit->bmih));
-      if (!bmih)
-        {
-          result = FALSE;
-          break;
-        }
-      bmih_set_x_pixels_per_meter (bmih,
-                                bmih_get_x_pixels_per_meter (avi_edit->bmih));
-      bmih_set_y_pixels_per_meter (bmih,
-                                bmih_get_y_pixels_per_meter (avi_edit->bmih));
-      length = bm_all_bytes (bmih);
-
-      name = start == end ? g_strdup (file) : g_strdup_printf (format, i);
-      /* bmihファイルを開く */
-      fio = fileio_open (name, FILEIO_ACCESS_ALL,
-                                    FILEIO_SHARE_READ, FILEIO_MODE_CREATE_NEW);
-      g_free (name);
-      if (!fio)
-        {
-          result = FALSE;
-          break;
-        }
-      if (fileio_write (fio, &bmfh, BMFH_SIZE) != BMFH_SIZE
-                                || fileio_write (fio, bmih, length) != length)
-        {
-          fileio_close (fio);
-          result = FALSE;
-          break;
-        }
-      if (!fileio_close (fio))
-        {
-          result = FALSE;
-          break;
-        }
-    }
-  g_free (format);
-  return avi_get_frame_close (avi_frame) && result;
-}
-
-
-/*  ja:WAVEファイルに保存する
-     avi_edit,AVI編集ハンドル
-         file,ファイル名
-         func,コールバック関数
-    user_data,データ
-          RET,TRUE:正常終了,FALSE:エラー                                    */
-gboolean
-avi_save_wave (AviEdit      *avi_edit,
-               const gchar  *file,
-               gboolean    (*func)(gint, gpointer),
-               gpointer      user_data)
-{
-  FileIO *fio;
-  gpointer head;
-  guint8 *p;
-  gint pos = 0, samples = AVI_PCM_SAMPLES_PER_SEC, written = 0, header;
-  AviPcm *avi_pcm;
-
-  if (!avi_edit || !file)
-    return FALSE;
-  /* ja:ヘッタサイズを計算する */
-  header = sizeof (guint32)                                     /* en:'RIFF' */
-            + sizeof (guint32)                                  /* ja:サイズ */
-            + sizeof (guint32)                                  /* en:'WAVE' */
-            + sizeof (guint32)                                  /* en:'fmt ' */
-            + sizeof (guint32)                                  /* ja:サイズ */
-            + ((wf_header_bytes (avi_edit->wfx) + 1) & ~1)      /* ja:構造体 */
-            + sizeof (guint32)                                  /* en:'data' */
-            + sizeof (guint32);                                 /* ja:サイズ */
-  /* ja:ファイルを開く */
-  fio = fileio_open (file, FILEIO_ACCESS_ALL,
-                                    FILEIO_SHARE_READ, FILEIO_MODE_CREATE_NEW);
-  if (!fio)
-    return FALSE;
-  if (fileio_seek (fio, header, FILEIO_SEEK_SET) == -1)
-    {
-      fileio_close (fio);
-      return FALSE;
-    }
-  /* ja:データ */
-  avi_pcm = avi_get_pcm_open (avi_edit);
-  if (!avi_pcm)
-    {
-      fileio_close (fio);
-      return FALSE;
-    }
-  while (pos < avi_length (avi_edit))
-    {
-      gpointer out_buf;
-      gint out_samples;
-      gint length;
-
-      /* ja:中断チェック */
-      if (func && !func (pos * 100 / avi_length (avi_edit), user_data))
-        break;
-      if (avi_length (avi_edit) < pos + samples)
-        samples = avi_length (avi_edit) - pos;
-      if (!avi_get_pcm (avi_pcm, pos, samples, &out_buf, &out_samples))
-        {
-          avi_get_pcm_close (avi_pcm);
-          fileio_close (fio);
-          return FALSE;
-        }
-      pos += samples;
-      length = out_samples * wfx_get_block_align (avi_edit->wfx);
-      if (fileio_write (fio, out_buf, length) != length)
-        {
-          avi_get_pcm_close (avi_pcm);
-          g_free (out_buf);
-          fileio_close (fio);
-          return FALSE;
-        }
-      g_free (out_buf);
-      written += length;
-    }
-  if (!avi_get_pcm_close (avi_pcm))
-    {
-      fileio_close (fio);
-      return FALSE;
-    }
-  if (written & 1)
-    {
-      const static guint8 dmy = 0;
-
-      if (fileio_write (fio, &dmy, 1) != 1)
-        {
-          fileio_close (fio);
-          return FALSE;
-        }
-    }
-  /* ja:ヘッタを設定する */
-  p = head = g_malloc (header);
-  *(guint32 *)p = GUINT32_TO_LE (CK_DEF_RIFF);
-  ((guint32 *)p)++;                                             /* en:'RIFF' */
-  *(guint32 *)p = GUINT32_TO_LE (header - sizeof (guint32) * 2
-                                                    + ((written + 1) & ~1));
-  ((guint32 *)p)++;                                             /* ja:サイズ */
-  *(guint32 *)p = GUINT32_TO_LE (CK_FORM_WAVE);
-  ((guint32 *)p)++;                                             /* en:'WAVE' */
-  *(guint32 *)p = GUINT32_TO_LE (CK_ID_WAVEFORMAT);
-  ((guint32 *)p)++;                                             /* en:'fmt ' */
-  *(guint32 *)p = GUINT32_TO_LE (wf_header_bytes (avi_edit->wfx));
-  ((guint32 *)p)++;                                             /* ja:サイズ */
-  g_memmove (p, avi_edit->wfx, wf_header_bytes (avi_edit->wfx));
-  if (wf_header_bytes (avi_edit->wfx) & 1)
-    p[wf_header_bytes (avi_edit->wfx)] = 0;
-  p += (wf_header_bytes (avi_edit->wfx) + 1) & ~1;
-  *(guint32 *)p = GUINT32_TO_LE (CK_ID_WAVEDATA);
-  ((guint32 *)p)++;                                             /* en:'data' */
-  *(guint32 *)p = GUINT32_TO_LE (written);                      /* ja:サイズ */
-  if (fileio_seek (fio, 0 , FILEIO_SEEK_SET) == -1
-                                || fileio_write (fio, head, header) != header)
-    {
-      fileio_close (fio);
-      g_free (head);
-      return FALSE;
-    }
-  g_free (head);
-  return fileio_close (fio);
-}
-
-
 /*  ja:ファイルに保存する
      avi_edit,AVI編集ハンドルへのポインタ
          file,ファイル名
@@ -1312,7 +1542,6 @@ avi_save_with_options (AviEdit      *avi_edit[],
                        gboolean    (*func)(gint, gpointer),
                        gpointer      user_data)
 {
-  FileIO *fio;
   gboolean result = FALSE;
   gchar *scenario;
 
@@ -1327,21 +1556,13 @@ avi_save_with_options (AviEdit      *avi_edit[],
                             avi_save->start, avi_save->end, func, user_data);
         break;
       case AVI_FILE_WAVE:
-        result = avi_save_wave (avi_edit[avi_save->stream], file,
+        return avi_save_wave (avi_edit[avi_save->stream], file,
+                        avi_save->avi_opt->wfx, avi_save->avi_opt->recompress,
                                                             func, user_data);
         break;
       default:
-        if ((scenario = avi_to_scenario (avi_edit, FALSE))
-                && (fio = fileio_open (file, FILEIO_ACCESS_ALL,
-                                FILEIO_SHARE_READ, FILEIO_MODE_CREATE_NEW)))
-          {
-            gssize length;
-
-            length = g_strlen (scenario);
-            result = fileio_write (fio, scenario, length) == length;
-            if (!fileio_close (fio))
-              result = FALSE;
-          }
+        result = (scenario = avi_to_scenario (avi_edit, FALSE))
+                        && fileio_save (file, scenario, g_strlen (scenario));
         g_free (scenario);
     }
   return result;
