@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -700,17 +700,35 @@ avi_from_scenario (const gchar *scenario)
           else if (avi_edit[i] && !avi_edit[i]->wfx
                                 && avi_type (avi_edit[i]) == AVI_TYPE_AUDIO)
             {
-              if (wfx_get_format_tag (avi_edit[i]->file->wfx)
-                                                            == WAVE_FORMAT_PCM)
+              if (wfx_get_format_tag (avi_edit[i]->file->wfx) == WAVE_FMT_PCM)
                 {
                   avi_edit[i]->wfx = g_memdup (avi_edit[i]->file->wfx,
                                     wf_header_bytes (avi_edit[i]->file->wfx));
                 }
               else
                 {
+                  AcmObject *acm_object;
+
                   /* ja:圧縮 */
-                  avi_release (avi_edit[i]);
-                  avi_edit[i] = NULL;
+                  acm_object = acm_open
+                                (wfx_get_format_tag (avi_edit[i]->file->wfx));
+                  if (acm_object && (avi_edit[i]->wfx
+                                    = g_malloc (acm_decompress_get_format_size
+                                        (acm_object, avi_edit[i]->file->wfx)))
+                        && (acm_decompress_get_format (acm_object,
+                                    avi_edit[i]->file->wfx, avi_edit[i]->wfx)
+                                                    & acm_close (acm_object)))
+                    {
+                      avi_edit[i]->rate
+                            = wfx_get_average_bytes_per_sec (avi_edit[i]->wfx);
+                      avi_edit[i]->scale
+                            = wfx_get_block_align (avi_edit[i]->wfx);
+                    }
+                  else
+                    {
+                      avi_release (avi_edit[i]);
+                      avi_edit[i] = NULL;
+                    }
                 }
             }
 #ifdef XXX
