@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ typedef struct _PaletteTableList
     table,パレットの分布                                                    */
 static void
 optimize (PaletteTableList *ptl,
-          guint             table[32][32][32])
+          const guint       table[32][32][32])
 {
   gint i, j;
 
@@ -105,7 +105,7 @@ static void
 divide_palette_count (PaletteTableList *p0,
                       PaletteTableList *p1,
                       PaletteTableList *p2,
-                      guint             table[32][32][32])
+                      const guint       table[32][32][32])
 {
   gint i, j;
 
@@ -195,7 +195,7 @@ static void
 divide_palette_area (PaletteTableList *p0,
                      PaletteTableList *p1,
                      PaletteTableList *p2,
-                     guint             table[32][32][32])
+                     const guint       table[32][32][32])
 {
   gint i, j, k, medium;
 
@@ -238,9 +238,9 @@ divide_palette_area (PaletteTableList *p0,
       rgb,パレットを格納するバッファ
     table,パレット分布立方体                                                */
 void
-bitmap_make_palette (const gint  count,
-                     RgbQuad    *rgb,
-                     guint       table[32][32][32])
+bitmap_make_palette (const gint   count,
+                     RgbQuad     *rgb,
+                     const guint  table[32][32][32])
 {
   gint i, j, k;
   guint max;
@@ -327,10 +327,11 @@ bitmap_make_palette (const gint  count,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_expand (BitmapInfoHeader *bmih0,
-               BitmapInfoHeader *bmih1)
+bitmap_expand (const BitmapInfoHeader *bmih0,
+               BitmapInfoHeader       *bmih1)
 {
-  gint c, i, n, x = 0, y = 0, length;
+  gsize length;
+  gint c, i, n, x = 0, y = 0;
   guint8 *p, *q;
 
   length = bm_header_bytes (bmih0);
@@ -453,13 +454,14 @@ bitmap_expand (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_approx_1 (BitmapInfoHeader *bmih0,
-                 BitmapInfoHeader *bmih1)
+bitmap_approx_1 (const BitmapInfoHeader *bmih0,
+                 BitmapInfoHeader       *bmih1)
 {
+  gsize length0, length1, pixel_bytes;
   gint i, j, k;
   gint blue, green, red;
   gint distance, dist_red, dist_blue, dist_green;
-  gint index, min, length0, length1, color_used, pixel_bytes;
+  gint index, min, color_used;
   guint8 *p, *q;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -520,13 +522,14 @@ bitmap_approx_1 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_approx_4 (BitmapInfoHeader *bmih0,
-                 BitmapInfoHeader *bmih1)
+bitmap_approx_4 (const BitmapInfoHeader *bmih0,
+                 BitmapInfoHeader       *bmih1)
 {
+  gsize length0, length1, pixel_bytes;
   gint i, j, k;
   gint blue, green, red;
   gint distance, dist_blue, dist_green, dist_red;
-  gint index, min, length0, length1, color_used, pixel_bytes;
+  gint index, min, color_used;
   guint8 *p, *q;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -586,13 +589,14 @@ bitmap_approx_4 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_approx_8 (BitmapInfoHeader *bmih0,
-                 BitmapInfoHeader *bmih1)
+bitmap_approx_8 (const BitmapInfoHeader *bmih0,
+                 BitmapInfoHeader       *bmih1)
 {
+  gsize length0, length1, pixel_bytes;
   gint i, j, k;
   gint blue, green, red;
   gint distance, dist_blue, dist_green, dist_red;
-  gint index, min, length0, length1, color_used, pixel_bytes;
+  gint index, min, color_used;
   guint8 *p, *q;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -652,16 +656,17 @@ bitmap_approx_8 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_diffuse_1 (BitmapInfoHeader *bmih0,
-                  BitmapInfoHeader *bmih1)
+bitmap_diffuse_1 (const BitmapInfoHeader *bmih0,
+                  BitmapInfoHeader       *bmih1)
 {
+  gsize length0, length1, pixel_bytes;
   gshort *buffer;
   gint i, j, k;
   gint blue, green, red;
   gint diagonal_blue, diagonal_green, diagonal_red;
   gint distance, dist_blue, dist_green, dist_red;
   gint next_blue, next_green, next_red;
-  gint index,min, length0, length1, color_used, pixel_bytes;
+  gint index,min, color_used;
   guint8 *p, *q;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -738,16 +743,17 @@ bitmap_diffuse_1 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_diffuse_4 (BitmapInfoHeader *bmih0,
-                  BitmapInfoHeader *bmih1)
+bitmap_diffuse_4 (const BitmapInfoHeader *bmih0,
+                  BitmapInfoHeader       *bmih1)
 {
+  gsize length0, length1, pixel_bytes;
   gshort *buffer;
   gint i, j, k;
   gint blue, green, red;
   gint diagonal_blue, diagonal_green, diagonal_red;
   gint distance, dist_blue, dist_green, dist_red;
   gint next_blue, next_green, next_red;
-  gint index, min, length0, length1, color_used, pixel_bytes;
+  gint index, min, color_used;
   guint8 *p, *q;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -824,16 +830,17 @@ bitmap_diffuse_4 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_diffuse_8 (BitmapInfoHeader *bmih0,
-                  BitmapInfoHeader *bmih1)
+bitmap_diffuse_8 (const BitmapInfoHeader *bmih0,
+                  BitmapInfoHeader       *bmih1)
 {
+  gsize length0, length1, pixel_bytes;
   gshort *buffer;
   gint i, j, k;
   gint blue, green, red;
   gint diagonal_blue, diagonal_green, diagonal_red;
   gint distance, dist_blue, dist_green, dist_red;
   gint next_blue, next_green, next_red;
-  gint index, min, length0, length1, color_used, pixel_bytes;
+  gint index, min, color_used;
   guint8 *p, *q;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -910,12 +917,13 @@ bitmap_diffuse_8 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_order_1 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1)
+bitmap_order_1 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1)
 {
-  gint i, j, length0, length1, pixel_bytes;
+  gsize length0, length1, pixel_bytes;
+  gint i, j;
   guint8 *p, *q;
-  gint bayer[2][2] = {{51, 153}, {204, 102}};
+  const gint bayer[2][2] = {{51, 153}, {204, 102}};
 
   bmih_set_size (bmih1, BMIH_SIZE);
   bmih_set_width (bmih1, bmih_get_width (bmih0));
@@ -949,12 +957,13 @@ bitmap_order_1 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_order_4 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1)
+bitmap_order_4 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1)
 {
-  gint i, j, index, length0, length1, order, pixel_bytes;
+  gsize length0, length1, pixel_bytes;
+  gint i, j, index, order;
   guint8 *p, *q;
-  gint bayer[2][2] = {{51, 153}, {204, 102}};
+  const gint bayer[2][2] = {{51, 153}, {204, 102}};
 
   bmih_set_size (bmih1, BMIH_SIZE);
   bmih_set_width (bmih1, bmih_get_width (bmih0));
@@ -1008,12 +1017,13 @@ bitmap_order_4 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_order_8 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1)
+bitmap_order_8 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1)
 {
-  gint i, j, length0, length1, order, pixel_bytes;
+  gsize length0, length1, pixel_bytes;
+  gint i, j, order;
   guint8 *p, *q;
-  gint bayer[2][2] = {{51, 153}, {204, 102}};
+  const gint bayer[2][2] = {{51, 153}, {204, 102}};
 
   bmih_set_size (bmih1, BMIH_SIZE);
   bmih_set_width (bmih1, bmih_get_width (bmih0));
@@ -1063,10 +1073,11 @@ bitmap_order_8 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_convert_16 (BitmapInfoHeader *bmih0,
-                   BitmapInfoHeader *bmih1)
+bitmap_convert_16 (const BitmapInfoHeader *bmih0,
+                   BitmapInfoHeader       *bmih1)
 {
-  gint i, j, length0, length1, pixel_bytes;
+  gsize length0, length1, pixel_bytes;
+  gint i, j;
   guint8 *p;
   guint16 *q;
 
@@ -1102,10 +1113,11 @@ bitmap_convert_16 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_convert_24 (BitmapInfoHeader *bmih0,
-                   BitmapInfoHeader *bmih1)
+bitmap_convert_24 (const BitmapInfoHeader *bmih0,
+                   BitmapInfoHeader       *bmih1)
 {
-  gint i, j, k, bit, index, length0, length1;
+  gsize length0, length1;
+  gint i, j, k, bit, index;
   guint32 mask[3], shift;
   guint8 *p, *q;
 
@@ -1256,11 +1268,12 @@ bitmap_convert_24 (BitmapInfoHeader *bmih0,
     bmih1,新しいビットマップへのポインタ
       rgb,背景色                                                            */
 void
-bitmap_convert_24_with_bgcolor (BitmapInfoHeader *bmih0,
-                                BitmapInfoHeader *bmih1,
-                                RgbQuad          *rgb)
+bitmap_convert_24_with_bgcolor (const BitmapInfoHeader *bmih0,
+                                BitmapInfoHeader       *bmih1,
+                                const RgbQuad          *rgb)
 {
-  gint i, j, alpha, bgcolor, length;
+  gsize length;
+  gint i, j, alpha, bgcolor;
   guint8 *p, *q;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -1300,10 +1313,11 @@ bitmap_convert_24_with_bgcolor (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_convert_32 (BitmapInfoHeader *bmih0,
-                   BitmapInfoHeader *bmih1)
+bitmap_convert_32 (const BitmapInfoHeader *bmih0,
+                   BitmapInfoHeader       *bmih1)
 {
-  gint i, j, k, bit, index, length0, length1;
+  gsize length0, length1;
+  gint i, j, k, bit, index;
   guint32 mask[3], shift;
   guint8 *p, *q;
 
@@ -1472,10 +1486,11 @@ bitmap_convert_32 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_1 (BitmapInfoHeader *bmih0,
-               BitmapInfoHeader *bmih1)
+bitmap_zoom_1 (const BitmapInfoHeader *bmih0,
+               BitmapInfoHeader       *bmih1)
 {
-  gint x0, y0, x1, y1, length0, length1;
+  gsize length0, length1;
+  gint x0, y0, x1, y1;
   guint8 *src, *dst;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -1509,10 +1524,11 @@ bitmap_zoom_1 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_4 (BitmapInfoHeader *bmih0,
-               BitmapInfoHeader *bmih1)
+bitmap_zoom_4 (const BitmapInfoHeader *bmih0,
+               BitmapInfoHeader       *bmih1)
 {
-  gint x0, y0, x1, y1, length0, length1;
+  gsize length0, length1;
+  gint x0, y0, x1, y1;
   guint8 *src, *dst;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -1546,10 +1562,11 @@ bitmap_zoom_4 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_8 (BitmapInfoHeader *bmih0,
-               BitmapInfoHeader *bmih1)
+bitmap_zoom_8 (const BitmapInfoHeader *bmih0,
+               BitmapInfoHeader       *bmih1)
 {
-  gint x0, y0, x1, y1, length0, length1;
+  gsize length0, length1;
+  gint x0, y0, x1, y1;
   guint8 *src, *dst;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -1581,10 +1598,11 @@ bitmap_zoom_8 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_16 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1)
+bitmap_zoom_16 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1)
 {
-  gint x0, y0, x1, y1, length0, length1;
+  gsize length0, length1;
+  gint x0, y0, x1, y1;
   guint16 *src, *dst;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -1616,10 +1634,11 @@ bitmap_zoom_16 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_24 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1)
+bitmap_zoom_24 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1)
 {
-  gint x0, y0, x1, y1, length0, length1;
+  gsize length0, length1;
+  gint x0, y0, x1, y1;
   guint8 *src, *dst;
 
   bmih_set_size (bmih1, BMIH_SIZE);
@@ -1653,8 +1672,8 @@ bitmap_zoom_24 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_32 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1)
+bitmap_zoom_32 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1)
 {
   guint x0, y0, x1, y1;
   guint32 *src, *dst;
@@ -1687,7 +1706,7 @@ bitmap_zoom_32 (BitmapInfoHeader *bmih0,
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom (BitmapInfoHeader *bmih0,
+bitmap_zoom (const BitmapInfoHeader *bmih0,
              BitmapInfoHeader *bmih1)
 {
   switch (bmih_get_bit_count (bmih0))
@@ -1709,11 +1728,11 @@ bitmap_zoom (BitmapInfoHeader *bmih0,
     y_overlay,X座標
         trans,透過色,TRUE:有効,FALSE:無効                                   */
 void
-bitmap_overlay_32 (BitmapInfoHeader *bmih0,
-                   BitmapInfoHeader *bmih1,
-                   gint              x_overlay,
-                   gint              y_overlay,
-                   gboolean          trans)
+bitmap_overlay_32 (const BitmapInfoHeader *bmih0,
+                   BitmapInfoHeader       *bmih1,
+                   const gint              x_overlay,
+                   const gint              y_overlay,
+                   const gboolean          trans)
 {
   gint i, index, alpha, bgcolor;
   gint x, y, width, height;
