@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include "sigmain.h"
 #include "thread.h"
 #include "misc/argument.h"
-#include "misc/misc.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
 
@@ -303,6 +302,8 @@ signal_selection_received (GtkWidget        *widget,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("AVI Clone Error"));
+                  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
                   gtk_dialog_run (GTK_DIALOG (dialog));
                   gtk_widget_destroy (dialog);
                   for (i = 0; i < 2; i++)
@@ -390,6 +391,8 @@ signal_selection_received (GtkWidget        *widget,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("AVI Paste Error"));
+              g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
               gtk_dialog_run (GTK_DIALOG (dialog));
               gtk_widget_destroy (dialog);
               for (i = 0; i < 2; i++)
