@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,10 +22,10 @@
 #include "command.h"
 #include "file.h"
 #include "general.h"
+#include "icons.h"
 #include "sigfile.h"
 #include "sigmain.h"
 #include "thread.h"
-#include "toolbar.h"
 #include "misc/argument.h"
 #include "misc/fileio.h"
 #include "misc/gnugpl.h"
@@ -74,62 +74,87 @@ GdkColor system_color[4] = {{0, 0x0000, 0x0000, 0x0000},
 UINT uFormat = 0;                   /* ja:クリップボード */
 #endif /* G_OS_WIN32 */
 MiscCreateMenuEntry menu_entries[] = {
-{"/",                     NULL,                         NULL,              MISC_CREATE_MENU_BAR,       NULL,             NULL, NULL},
-{"/file",                 N_("_File"),                  NULL,              MISC_CREATE_MENU_ITEM,      NULL,             NULL, NULL},
-{"/file/",                NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,             NULL, NULL},
-{"/file/new",             N_("_New"),                   "<control>N",      MISC_CREATE_MENU_ITEM,      command_new,      NULL, NULL},
-{"/file/open",            N_("_Open..."),               "<control>O",      MISC_CREATE_MENU_ITEM,      command_open,     NULL, NULL},
-{"/file/close",           N_("_Close"),                 "<control>W",      MISC_CREATE_MENU_ITEM,      command_close,    NULL, NULL},
-{"/file/saveas",          N_("_Save _As..."),           "<control>S",      MISC_CREATE_MENU_ITEM,      command_save,     NULL, NULL},
-{"/file/sep1",            NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,             NULL, NULL},
-{"/file/preview",         N_("Pre_view..."),            "<control>P",      MISC_CREATE_MENU_ITEM,      NULL,             NULL, NULL},
-{"/file/properties",      N_("Propert_ies..."),         "<alt>Return",     MISC_CREATE_MENU_ITEM,      command_property, NULL, NULL},
-{"/file/sep2",            NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,             NULL, NULL},
-{"/file/exit",            N_("E_xit"),                  "<control>Q",      MISC_CREATE_MENU_ITEM,      command_exit,     NULL, NULL},
-{"/edit",                 N_("_Edit"),                  NULL,              MISC_CREATE_MENU_ITEM,      NULL,             NULL, NULL},
-{"/edit/",                NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,             NULL, NULL},
-{"/edit/undo",            N_("_Undo"),                  "<control>Z",      MISC_CREATE_MENU_ITEM,      command_undo,     NULL, NULL},
-{"/edit/redo",            N_("_Redo"),                  "F4",              MISC_CREATE_MENU_ITEM,      command_redo,     NULL, NULL},
-{"/edit/sep1",            NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,             NULL, NULL},
-{"/edit/cut",             N_("Cu_t"),                   "<control>X",      MISC_CREATE_MENU_ITEM,      command_cut,      NULL, NULL},
-{"/edit/copy",            N_("_Copy"),                  "<control>C",      MISC_CREATE_MENU_ITEM,      command_copy,     NULL, NULL},
-{"/edit/paste",           N_("_Paste"),                 "<control>V",      MISC_CREATE_MENU_ITEM,      command_paste,    NULL, NULL},
-{"/edit/delete",          N_("De_lete"),                NULL,              MISC_CREATE_MENU_ITEM,      command_delete,   NULL, NULL},
-{"/edit/sep2",            NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,             NULL, NULL},
-{"/edit/merge",           N_("_Merge..."),              "<control>M",      MISC_CREATE_MENU_ITEM,      NULL,             NULL, NULL},
-{"/edit/jump",            N_("_Jump..."),               "<control>J",      MISC_CREATE_MENU_ITEM,      command_jump,     NULL, NULL},
-{"/edit/sep3",            NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,             NULL, NULL},
-{"/edit/all",             N_("_All"),                   "<control>A",      MISC_CREATE_MENU_ITEM,      command_all,      NULL, NULL},
-{"/view",                 N_("_View"),                  NULL,              MISC_CREATE_MENU_ITEM,      NULL,             NULL, NULL},
-{"/view/",                NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,             NULL, NULL},
-{"/view/size",            N_("S_ize..."),               NULL,              MISC_CREATE_MENU_ITEM,      command_size,     NULL, NULL},
-{"/option",               N_("_Option"),                NULL,              MISC_CREATE_MENU_ITEM,      NULL,             NULL, NULL},
-{"/option/",              NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,             NULL, NULL},
-{"/option/configuration", N_("_Configuration..."),      NULL,              MISC_CREATE_MENU_ITEM,      command_conf,     NULL, NULL},
-{"/task",                 N_("_Task"),                  NULL,              MISC_CREATE_MENU_ITEM,      NULL,             NULL, NULL},
-{"/task/",                NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,             NULL, NULL},
-{"/task/size",            N_("_Cancel"),                NULL,              MISC_CREATE_MENU_ITEM,      command_cancel,   NULL, NULL},
-{"/window",               N_("_Window"),                NULL,              MISC_CREATE_MENU_ITEM,      NULL,             NULL, NULL},
-{"/window/",              NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,             NULL, NULL},
-{"/help",                 N_("_Help"),                  NULL,              MISC_CREATE_MENU_ITEM,      NULL,             NULL, NULL},
-{"/help/",                NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,             NULL, NULL},
-{"/help/about",           N_("_About..."),              NULL,              MISC_CREATE_MENU_ITEM,      command_version,  NULL, NULL},
-{NULL,                    NULL,                         NULL,              MISC_CREATE_MENU_TERMINAL,  NULL,             NULL, NULL}};
+{"/",                     NULL,                  NULL,          MISC_CREATE_MENU_BAR,                               NULL,             NULL, NULL},
+{"/file",                 N_("_File"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/file/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/file/new",             GTK_STOCK_NEW,         NULL,          MISC_CREATE_MENU_STOCK,                             command_new,      NULL, NULL},
+{"/file/open",            GTK_STOCK_OPEN,        NULL,          MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_open,     NULL, NULL},
+{"/file/close",           GTK_STOCK_CLOSE,       NULL,          MISC_CREATE_MENU_STOCK,                             command_close,    NULL, NULL},
+{"/file/saveas",          GTK_STOCK_SAVE_AS,     "<control>S",  MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_save,     NULL, NULL},
+{"/file/sep1",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/file/preview",         N_("Pre_view"),        "<control>P",  MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/file/properties",      GTK_STOCK_PROPERTIES,  "<alt>Return", MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_property, NULL, NULL},
+{"/file/sep2",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/file/exit",            GTK_STOCK_QUIT,        NULL,          MISC_CREATE_MENU_STOCK,                             command_exit,     NULL, NULL},
+{"/edit",                 N_("_Edit"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/edit/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/edit/undo",            GTK_STOCK_UNDO,        "<control>Z",  MISC_CREATE_MENU_STOCK,                             command_undo,     NULL, NULL},
+{"/edit/redo",            GTK_STOCK_REDO,        "F4",          MISC_CREATE_MENU_STOCK,                             command_redo,     NULL, NULL},
+{"/edit/sep1",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/edit/cut",             GTK_STOCK_CUT,         NULL,          MISC_CREATE_MENU_STOCK,                             command_cut,      NULL, NULL},
+{"/edit/copy",            GTK_STOCK_COPY,        NULL,          MISC_CREATE_MENU_STOCK,                             command_copy,     NULL, NULL},
+{"/edit/paste",           GTK_STOCK_PASTE,       NULL,          MISC_CREATE_MENU_STOCK,                             command_paste,    NULL, NULL},
+{"/edit/delete",          GTK_STOCK_DELETE,      NULL,          MISC_CREATE_MENU_STOCK,                             command_delete,   NULL, NULL},
+{"/edit/sep2",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/edit/merge",           N_("_Merge"),          "<control>M",  MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  NULL,             NULL, NULL},
+{"/edit/jump",            GTK_STOCK_JUMP_TO,     "<control>J",  MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_jump,     NULL, NULL},
+{"/edit/sep3",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+#if GTK_CHECK_VERSION(2,10,0)
+{"/edit/all",             GTK_STOCK_SELECT_ALL,  "<control>A",  MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
+#else /* not GTK_CHECK_VERSION(2,10,0) */
+{"/edit/all",             N_("_All"),            "<control>A",  MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
+#endif /* not GTK_CHECK_VERSION(2,10,0) */
+{"/view",                 N_("_View"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/view/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/view/size",            N_("S_ize"),           NULL,          MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_size,     NULL, NULL},
+{"/option",               N_("_Option"),         NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/option/",              NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/option/configuration", GTK_STOCK_PREFERENCES, NULL,          MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_conf,     NULL, NULL},
+{"/task",                 N_("_Task"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/task/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/task/size",            GTK_STOCK_CANCEL,      NULL,          MISC_CREATE_MENU_STOCK,                             command_cancel,   NULL, NULL},
+{"/window",               N_("_Window"),         NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/window/",              NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/help",                 N_("_Help"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/help/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/help/about",           N_("_About"),          NULL,          MISC_CREATE_MENU_ITEM,                              command_version,  NULL, NULL},
+{NULL,                    NULL,                  NULL,          MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL, NULL}};
 MiscCreateMenuEntry popup_entries[] = {
-{"/",                     NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,            NULL},
-{"/undo",                 N_("_Undo"),                   "<control>Z", MISC_CREATE_MENU_ITEM,      command_undo,     NULL,            NULL},
-{"/sep1",                 NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
-{"/cut",                  N_("Cu_t"),                    "<control>X", MISC_CREATE_MENU_ITEM,      command_cut,      NULL,            NULL},
-{"/copy",                 N_("_Copy"),                   "<control>C", MISC_CREATE_MENU_ITEM,      command_copy,     NULL,            NULL},
-{"/paste",                N_("_Paste"),                  "<control>V", MISC_CREATE_MENU_ITEM,      command_paste,    NULL,            NULL},
-{"/delete",               N_("De_lete"),                 NULL,         MISC_CREATE_MENU_ITEM,      command_delete,   NULL,            NULL},
-{"/sep2",                 NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
-{"/all",                  N_("_All"),                    "<control>A", MISC_CREATE_MENU_ITEM,      command_all,      NULL,            NULL},
-{NULL,                    NULL,                          NULL,         MISC_CREATE_MENU_TERMINAL,  NULL,             NULL,            NULL}};
+{"/",                     NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/undo",                 GTK_STOCK_UNDO,        "<control>Z",  MISC_CREATE_MENU_STOCK,                             command_undo,     NULL, NULL},
+{"/sep1",                 NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/cut",                  GTK_STOCK_CUT,         NULL,          MISC_CREATE_MENU_STOCK,                             command_cut,      NULL, NULL},
+{"/copy",                 GTK_STOCK_COPY,        NULL,          MISC_CREATE_MENU_STOCK,                             command_copy,     NULL, NULL},
+{"/paste",                GTK_STOCK_PASTE,       NULL,          MISC_CREATE_MENU_STOCK,                             command_paste,    NULL, NULL},
+{"/delete",               GTK_STOCK_DELETE,      NULL,          MISC_CREATE_MENU_STOCK,                             command_delete,   NULL, NULL},
+{"/sep2",                 NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+#if GTK_CHECK_VERSION(2,10,0)
+{"/all",                  GTK_STOCK_SELECT_ALL,  "<control>A",  MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
+#else /* not GTK_CHECK_VERSION(2,10,0) */
+{"/all",                  N_("_All"),            "<control>A",  MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
+#endif /* not GTK_CHECK_VERSION(2,10,0) */
+{NULL,                    NULL,                  NULL,          MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL, NULL}};
 MiscCreateMenuEntry tview_entries[] = {
-{"/",                     NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,            NULL},
-{"/cancel",               N_("_Cancel"),                 NULL,         MISC_CREATE_MENU_ITEM,      command_cancel,   NULL,            NULL},
-{NULL,                    NULL,                          NULL,         MISC_CREATE_MENU_TERMINAL,  NULL,             NULL,            NULL}};
+{"/",                     NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/cancel",               GTK_STOCK_CANCEL,      NULL,          MISC_CREATE_MENU_STOCK,                             command_cancel,   NULL, NULL},
+{NULL,                    NULL,                  NULL,          MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL, NULL}};
+MiscCreateToolbarEntry toolbar_entries[] = {
+{"new",        GTK_STOCK_NEW,        NULL,           command_new,      NULL, NULL},
+{"open",       GTK_STOCK_OPEN,       NULL,           command_open,     NULL, NULL},
+{"saveas",     GTK_STOCK_SAVE_AS,    NULL,           command_save,     NULL, NULL},
+{"sep1",       NULL,                 NULL,           NULL,             NULL, NULL},
+{"properties", GTK_STOCK_PROPERTIES, NULL,           command_property, NULL, NULL},
+{"sep2",       NULL,                 NULL,           NULL,             NULL, NULL},
+{"preview",    N_("Preview"),        tb_preview_xpm, NULL,             NULL, NULL},
+{"sep3",       NULL,                 NULL,           NULL,             NULL, NULL},
+{"cut",        GTK_STOCK_CUT,        NULL,           command_cut,      NULL, NULL},
+{"copy",       GTK_STOCK_COPY,       NULL,           command_copy,     NULL, NULL},
+{"paste",      GTK_STOCK_PASTE,      NULL,           command_paste,    NULL, NULL},
+{"delete",     GTK_STOCK_DELETE,     NULL,           command_delete,   NULL, NULL},
+{"sep4",       NULL,                 NULL,           NULL,             NULL, NULL},
+{"undo",       GTK_STOCK_UNDO,       NULL,           command_undo,     NULL, NULL},
+{"redo",       GTK_STOCK_REDO,       NULL,           command_redo,     NULL, NULL},
+{NULL,         NULL,                 NULL,           NULL,             NULL, NULL}};
 
 
 /******************************************************************************
@@ -167,7 +192,7 @@ main (int   argc,
   /* en:Drag&Drop */
   GtkTargetEntry drag_types[1] = {{"text/uri-list", 0, 0}};
   /* ja:Video maidが提供可能なセレクション */
-  GtkTargetEntry targets_vmaid[]
+  GtkTargetEntry targets[1]
                         = {{"Video maid Scenario Object", 0, TARGET_VMAID}};
   static gchar *xpm0[] = {
 "4 8 2 1",
@@ -376,6 +401,16 @@ VMAID_COPYRIGHT_NOTICE"\n"
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), "Video maid");
   gtk_window_set_default_size (GTK_WINDOW (window), def_width, def_height);
+  glist = g_list_append (NULL, gdk_pixbuf_new_from_xpm_data (vmaid16_xpm));
+  glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (vmaid24_xpm));
+  glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (vmaid32_xpm));
+  glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (vmaid48_xpm));
+  gtk_window_set_icon_list (GTK_WINDOW (window), glist);
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 0)));
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 1)));
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 2)));
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 3)));
+  g_list_free (glist);
   g_signal_connect (G_OBJECT (window), "delete-event",
                                             G_CALLBACK (signal_delete), NULL);
   g_signal_connect (G_OBJECT (window), "destroy",
@@ -392,10 +427,10 @@ VMAID_COPYRIGHT_NOTICE"\n"
   uFormat = RegisterClipboardFormat (_T("Video maid Scenario Object"));
 #endif /* G_OS_WIN32 */
   /* ja:クリップボード */
-  atom_targets = gdk_atom_intern( "TARGETS", FALSE);
-  atom_scenario = gdk_atom_intern( "Video maid Scenario Object", FALSE);
+  atom_targets = gdk_atom_intern ("TARGETS", FALSE);
+  atom_scenario = gdk_atom_intern ("Video maid Scenario Object", FALSE);
   gtk_selection_add_targets (window, GDK_SELECTION_CLIPBOARD,
-            targets_vmaid, sizeof (targets_vmaid) / sizeof (GtkTargetEntry));
+                                            targets, G_N_ELEMENTS (targets));
   g_signal_connect (G_OBJECT (window), "selection-clear-event",
                                 G_CALLBACK (signal_selection_clear), NULL);
   g_signal_connect (G_OBJECT(window), "selection-get",
@@ -514,7 +549,6 @@ VMAID_COPYRIGHT_NOTICE"\n"
   gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/task"), FALSE);
   gtk_widget_show_all (window);
   gtk_widget_hide_all (text);
-  gtk_window_set_policy (GTK_WINDOW (window), FALSE, TRUE, TRUE);
 
   /* ja:ピクスマップ */
   pixmap = gdk_pixmap_create_from_xpm_d (window->window, &bitmap0, NULL, xpm0);
